@@ -397,9 +397,64 @@ ggthemes_data <- {
           "#39737C",
           "#86B4A9",
           "#82853B",
-          "#CCC94D")
+          "#CCC94D"),
         ## greenorange6 is odd
+        cyclic =
+        c("#1F83B4",
+          "#1696AC",
+          "#18A188",
+          "#29A03C",
+          "#54A338",
+          "#82A93F",
+          "#ADB828",
+          "#D8BD35",
+          "#FFBD4C",
+          "#FFB022",
+          "#FF9C0E",
+          "#FF810E",
+          "#E75727",
+          "#D23E4E",
+          "#C94D8C",
+          "#C04AA7",
+          "#B446B3",
+          "#9658B1",
+          "#8061B4",
+          "#6F63BB")
         )
+    x$tableau$sequential <-
+        list(`Red` = c(low = "#BCCFB4", high = "#9C0824"),
+             `Green` = c(low = "#BCCFB4", high = "#09622A"),
+             `Blue` = c(low = "#B4D4DA", high = "#26456E"),
+             `Orange` = c(low = "#F0C294", high = "#7B3014"),
+             `Gray` = c(low = "#C3C3C3", high = "#1E1E1E"),
+             `Red Light` = c(low = "#E5E5E5", high = "#FFB2B6"),
+             `Green Light` = c(low = "#E5E5E5", high = "#B7E6A7"),
+             `Blue Light` = c(low = "#E5E5E5", high = "#C4D8F3"),
+             `Orange Light` = c(low = "#E5E5E5", high = "#FFCC9E"),
+             `Area Red` = c(low = "#F5CAC7", high = "#BD1100"),
+             `Area Green` = c(low = "#DBE8B4", high = "#3C8200"),
+             `Area Brown` = c(low = "#F3E0C2", high = "#BB5137"),
+             `Blue-Green Sequential` = c(low = "#FEFFD9", high = "#41B7C4"),
+             `Brown Sequential` = c(low = "#F7E4C6", high = "#BB5137"),
+             `Purple Sequential` = c(low = "#EFEDF5", high = "#807DBA"),
+             `Grey Sequential` = c(low = "#F0F0F0", high = "#737373"))
+    x$tableau$diverging <-
+        list(`Red-Blue` = c(low="#9C0824", mid="#CACACA", high="#26456E"),
+             `Red-Green` = c(low="#9C0824", mid="#CACACA", high="#09622A"),
+             `Red-White-Green` = c(low="#9C0824", mid="#FFFFFF", high="#09622A"),
+             `Red-Black` = c(low="#9C0824", mid="#CACACA", high="#1E1E1E"),
+             `Red-White-Black` = c(low="#9C0824", mid="#FFFFFF", high="#1E1E1E"),
+             `Green-Blue` = c(low="#09622A", mid="#CACACA", high="#26456E"),
+             `Orange-Blue` = c(low="#7B3014", mid="#CACACA", high="#26456E"),
+             `Orange-White-Blue` = c(low="#7B3014", mid="#FFFFFF", high="#26456E"),
+             `Red-Green Light` = c(low="#FFB2B6", mid="#E5E5E5", high="#B7E6A7"),
+             `Red-White-Green Light` = c(low="#FFB2B6", mid="#FFFFFF", high="#B7E6A7"),
+             `Red-White-Black Light` = c(low="#FFB2B6", mid="#FFFFFF", high="#C6C6C6"),
+             `Orange-Blue Light` = c(low="#FFCC9E", mid="#E5E5E5", high="#C4D8F3"),
+             `Orange-White-Blue Light` = c(low="#FFCC9E", mid="#FFFFFF", high="#C4D8F3"),
+             `Orange-Blue` = c(low="#E0AD30", mid="#E4E4E2", high="#7492AA"),
+             `Light Red-Green` = c(low="#EDA389", mid="#CDE1D3", high="#5C8B70"),
+             `Temperature` = c(low="#529985", mid="#DBCF47", high="#C26B51"))
     x$tableau$shapes <-
     list(proportions = c(#
          -0x25CBL, # White circle
@@ -507,6 +562,62 @@ ggthemes_data <- {
                       vermillion="#D55E00",
                       reddish_purple="#CC79A7")
 
+    ## 
+    x$gdocs <-
+        c(rgb(51, 102, 204, max = 255),
+          rgb(220, 57, 18, max = 255),
+          rgb(255, 153, 0, max = 255),
+          rgb(16, 150, 24, max = 255),
+          rgb(153, 0, 153, max = 255),
+          rgb(0, 153, 198, max = 255),
+          rgb(221, 68, 119, max = 255),
+          rgb(102, 170, 0, max = 255),
+          rgb(184, 46, 46, max = 255),
+          rgb(49, 99, 149, max = 255),
+          rgb(153, 68, 153, max = 255),
+          rgb(34, 170, 153, max = 255),
+          rgb(170, 170, 17, max = 255),
+          rgb(102, 51, 204, max = 255),
+          rgb(230, 115, 0, max = 255),
+          rgb(139, 7, 7, max = 255),
+          rgb(101, 16, 103, max = 255),
+          rgb(50, 146, 98, max = 255),
+          rgb(85, 116, 166, max = 255),
+          rgb(59, 62, 172, max = 255))
+
+    x$calc <-
+      list(colors = 
+           c(`Chart 1` = "#004586",
+             `Chart 2` = "#FF420E",
+             `Chart 3` = "#FFD320",
+             `Chart 4` = "#579D1C",
+             `Chart 5` = "#7E0021",
+             `Chart 6` = "#83CAFF",
+             `Chart 7` = "#314004",
+             `Chart 8` = "#AECF00",
+             `Chart 9` = "#4B1F6F",
+             `Chart 10` = "#FF950E",
+             `Chart 11` = "#C5000B",
+             `Chart 12` = "#0084D1"),
+           shapes =
+           c(15L, # filled square
+             18L, # filled diamond
+             -0x25bc, # black down-pointing triangle
+             -0x25b2, # black up-pointing triangle
+             -0x25b6, # black right-pointing triangle
+             -0x25c0, # black left-pointing triangle
+             -0x29d3, # black bowtie
+             -0x29d7, # black hourglass
+             19L, # circle
+             -0x2726, # black four pointed star
+             4L, # x (0xd7)
+             3L, # plus (0x2b)
+             -0x2217, # asterisk operator
+             -0x2796, # heavy minus sign
+             -0x2759 # medium vertical bar)
+             ))
+    
     ## Return
     x
+
 }
